==> kspline-0.2.tgz: kspl/kspline/ksplinedlg.cpp <==
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
//#include <klocale.h>
#include "ksplinedlg.h"
#include "ksplinedlg.moc"
#include <kapp.h> // hier ist 'klocale' definiert !!!
//#define TRS klocale->translate

KSplineDlg::KSplineDlg(SplineCurve* Spl,QWidget* parent=0, const char* name=0):
     QDialog (parent, name, WStyle_DialogBorder)
{
// Einstellungsdialoch
char Strg[20];

   setFixedSize(250,200);
   Spline = Spl;
   
   NaturalCheck = new QCheckBox(klocale->translate("natural Spline"), this, "KubischCheck");
   NaturalCheck->setGeometry(10,20,150,20);
   NaturalCheck->setChecked(Spline->natural());

   QLabel* Label1 = new QLabel("Y1", this, "Y1Edit");
   Label1->setGeometry(10,60,40,20);
   QLabel* Label2 = new QLabel("Yn", this, "YnEdit");
   Label2->setGeometry(10,90,40,20);

   Y1Edit = new KRestrictedLine(this, "Y1Edit", "01234567890.eE+-");
   Y1Edit->setGeometry(50,60,100,20);
   sprintf(Strg, "%0.3f", Spline->getY1());
   Y1Edit->setText(Strg);

   YnEdit = new KRestrictedLine(this, "YnEdit", "01234567890.eE+-");
   YnEdit->setGeometry(50,90,100,20);
   sprintf(Strg, "%0.3f", Spline->getYn());
   YnEdit->setText(Strg);
   
   // OK-Button
   QPushButton *OkBtn = new QPushButton(klocale->translate("OK"), this, "OkBtn");
   OkBtn->setGeometry(10,170,80,30);
   connect(OkBtn, SIGNAL(clicked()), SLOT(accept()) );

   // cancel-Button
   QPushButton *AbortBtn = new QPushButton(klocale->translate("Cancel"), this, "OkBtn");
   AbortBtn->setGeometry(110,170,80,30);
   connect(AbortBtn, SIGNAL(clicked()), SLOT(reject()) );
}

int KSplineDlg::setParams(void) {
char* eptr;
double d1,d2;

   d1 = strtod(Y1Edit->text(), &eptr);
   if (*eptr!=0) return FALSE;
   d2 = strtod(YnEdit->text(), &eptr);
   if (*eptr!=0) return FALSE;
   
   Spline->setY1(d1);
   Spline->setYn(d2);
   Spline->setNatural(NaturalCheck->isChecked());
   return TRUE;
}

==> kspline-0.22.tgz: kspl/kspline/ksplinedlg.cpp <==
/*
    This file is part of the KDE libraries
    Copyright (C) 1998 Jrgen Hochwald (juergen.hochwald@privat.kkf.net

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this library; see the file COPYING.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.*/


#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
//#include <klocale.h>
#include "ksplinedlg.h"
#include "ksplinedlg.moc"
#include <kapp.h> // hier ist 'klocale' definiert !!!
//#define TRS klocale->translate

KSplineDlg::KSplineDlg(SplineCurve* Spl,QWidget* parent=0, const char* name=0):
     QDialog (parent, name, WStyle_DialogBorder)
{
// Einstellungsdialoch
char Strg[20];

   setFixedSize(250,200);
   Spline = Spl;
   
   NaturalCheck = new QCheckBox(klocale->translate("natural Spline"), this, "KubischCheck");
   NaturalCheck->setGeometry(10,20,150,20);
   NaturalCheck->setChecked(Spline->natural());

   QLabel* Label1 = new QLabel("Y1", this, "Y1Edit");
   Label1->setGeometry(10,60,40,20);
   QLabel* Label2 = new QLabel("Yn", this, "YnEdit");
   Label2->setGeometry(10,90,40,20);

   Y1Edit = new KRestrictedLine(this, "Y1Edit", "01234567890.eE+-");
   Y1Edit->setGeometry(50,60,100,20);
   sprintf(Strg, "%0.3f", Spline->getY1());
   Y1Edit->setText(Strg);

   YnEdit = new KRestrictedLine(this, "YnEdit", "01234567890.eE+-");
   YnEdit->setGeometry(50,90,100,20);
   sprintf(Strg, "%0.3f", Spline->getYn());
   YnEdit->setText(Strg);
   
   // OK-Button
   QPushButton *OkBtn = new QPushButton(klocale->translate("OK"), this, "OkBtn");
   OkBtn->setGeometry(10,170,80,30);
   connect(OkBtn, SIGNAL(clicked()), SLOT(accept()) );

   // cancel-Button
   QPushButton *AbortBtn = new QPushButton(klocale->translate("Cancel"), this, "OkBtn");
   AbortBtn->setGeometry(110,170,80,30);
   connect(AbortBtn, SIGNAL(clicked()), SLOT(reject()) );
}

int KSplineDlg::setParams(void) {
char* eptr;
double d1,d2;

   d1 = strtod(Y1Edit->text(), &eptr);
   if (*eptr!=0) return FALSE;
   d2 = strtod(YnEdit->text(), &eptr);
   if (*eptr!=0) return FALSE;
   
   Spline->setY1(d1);
   Spline->setYn(d2);
   Spline->setNatural(NaturalCheck->isChecked());
   return TRUE;
}
